@@ -17,6 +17,6 @@ class Command(BaseCommand):
         if settings.DEBUG:
             logger.warning('Disable DJANGO debug mode')
 
-        logger.info('Start tasks')
+        logger.info('Start future tasks')
         start()
-        logger.info('Finish tasks')
+        logger.info('Start future tasks')
