@@ -1,6 +1,5 @@
 # Django
 from django.db.models.signals import post_save
-from django.forms.models import model_to_dict
 from django.conf import settings
 
 # Project
@@ -14,7 +13,10 @@ def signal_post_save(sender, instance, created, **kwargs):
 def send(routing_key):
     @staticmethod
     def wrapper(instances):
-        JobClient().call(routing_key, [i.__dict__ for i in instances])
+        JobClient().call(
+            routing_key,
+            [getattr(i, 'serialized_data', i.__dict__) for i in instances]
+        )
 
     return wrapper
 
@@ -32,6 +34,9 @@ def producer(model):
 
     job_tasks(app_name, model=model)(sync_model)
 
+    if hasattr(model, 'post_save_trigger'):
+        return model
+
     if not hasattr(model, 'signal_post_save'):
         model.signal_post_save = signal_post_save
 
